import requests
import json
from .errors import *


class abcRoute:
    def __init__(self, data):
        self.route=data["route"]
        self.service_type=str(data["service_type"])
        if self.service_type == "1":
            self.normal=True
        else:
            self.normal=False
        self.bound=data["bound"]
        self.direction=data["bound"]
        self.stops_id={}
        for stop in json.loads(requests.get("https://data.etabus.gov.hk/v1/transport/kmb/route-stop").content.decode("utf-8"))["data"]:
            if stop["route"] == self.route and stop["bound"] == self.bound and stop["service_type"] == self.service_type:
                self.stops_id[stop["seq"]]=stop["stop"]


class Routes:
    def get(route: str, bound: str="O", service_type: str="1"):
        match bound.lower():
            case "o":
                bound="outbound"
            case "outbound":
                bound="outbound"
            case "ob":
                bound="outbound"
            case "i":
                bound="inbound"
            case "inbound":
                bound="inbound"
            case "ib":
                bound="inbound"
            case _:
                raise BoundError("Bound does not follow the format! Bound不遵循格式!")
        _data=json.loads(requests.get(f"https://data.etabus.gov.hk/v1/transport/kmb/route/{route}/{bound}/{service_type}").content.decode(encoding="utf-8"))
        if "code" in _data:
            raise RouteNotFound("API cannot get route! API無法取得路線!")
        elif _data["data"] == {}:
            raise RouteNotFound("API cannot get route! API無法取得路線!")
        else:
            return abcRoute(_data["data"])
        

    def all():
        _data=json.loads(requests.get("https://data.etabus.gov.hk/v1/transport/kmb/route/").content.decode("utf-8"))
        _list=[]
        for _route_data in _data["data"]:
            _list.append({"route": _route_data["route"], "bound": _route_data["bound"], "service_type": _route_data["service_type"]})
        return _list


import requests
import json
from .errors import *


class abcStop:
    def __init__(self, data):
        self.id=data["stop"]
        self.name={
            "en": data["name_en"],
            "tc": data["name_tc"],
            "sc": data["name_sc"]
        }


class Stops:
    def get(id: str):
        _data=json.loads(requests.get(f"https://data.etabus.gov.hk/v1/transport/kmb/stop/{id}").content.decode(encoding="utf-8"))
        if _data["data"] == {}:
            raise StopNotFound("API cannot get stop! API無法取得巴士站!")
        else:
            return abcStop(_data["data"])
        

    def all():
        _data=json.loads(requests.get("https://data.etabus.gov.hk/v1/transport/kmb/stop/").content.decode(encoding="utf-8"))
        _list=[]
        for _stop_data in _data["data"]:
            _list.append(_stop_data["stop"])
        return _list


import requests
import json
from .routes import abcRoute
from .stops import abcStop
from .errors import *


class abcETA:
    def __init__(self, data):
        self.company=data["co"]
        self.route=data["route"]
        self.bound=data["dir"]
        self.direction=data["dir"]
        self.service_type=str(data["service_type"])
        if data["eta"] == None:
            self.arrive_at="No Service"
        else:
            self.arrive_at=data["eta"].replace("T", " ")[:-6]
        self.sequence=str(data["eta_seq"])
        self.seq=self.sequence
        self.remark={
            "en": data["rmk_en"],
            "tc": data["rmk_tc"],
            "sc": data["rmk_sc"]
        }
        self.rmk=self.remark
        self.destination={
            "tc": data["dest_tc"],
            "en": data["dest_en"],
            "sc": data["dest_sc"]
        }
        self.dest=self.destination


class ETA:
    def get_route_stop(route: abcStop, stop: abcStop):
        _data=json.loads(requests.get(f"https://data.etabus.gov.hk/v1/transport/kmb/eta/{stop.id}/{route.route}/{route.service_type}").content.decode("utf-8"))
        _list=[]
        for _data in _data["data"]:
            _list.append(abcETA(_data))
        return _list
    

    def get_stop(stop: abcStop):
        _data=json.loads(requests.get(f"https://data.etabus.gov.hk/v1/transport/kmb/stop-eta/{stop.id}").content.decode("utf-8"))
        _list=[]
        for _route_data in _data["data"]:
            _list.append(abcETA(_route_data))
        return _list
    

    def get_route(route: abcStop):
        _data=json.loads(requests.get(f"https://data.etabus.gov.hk/v1/transport/kmb/route-eta/{route.route}/{route.service_type}").content.decode("utf-8"))
        _list=[]
        for _route_data in _data["data"]:
            _list.append(abcETA(_route_data))
        return _list


import setuptools

setuptools.setup(
    name="bushk",
    version=input("v -> "),
    author="MaxPython110331",
    description="取得香港巴士的數據!",
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/max-github110331/bushk",                                         
    packages=["bushk"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["requests"],
    python_requires=">=3.10"
)